---
name: Feature request
about: Suggest an idea for this project
title: "[ENH]"
labels: enhancement
assignees: ''

---

**What's your wish ?**

Concise description of what you would like to do with `qmat`, that is currently not implemented ...

**Alternative and possible solutions**

How you imagine your wish could be granted ...

**Additional details**

Add any other details that add some context (you can be more verbose here ...)
